Module uim.codec.parser.decoder.base
====================================

Classes
-------

`CodecDecoder()`
:   Abstract content parser for the different versions of the Universal Ink Model.

    ### Ancestors (in MRO)

    * abc.ABC

    ### Descendants

    * uim.codec.parser.decoder.decoder_3_0_0.UIMDecoder300
    * uim.codec.parser.decoder.decoder_3_1_0.UIMDecoder310